@@ -30,6 +30,7 @@ from sandroid.features.trigdroid import Trigdroid
 
 from .adb import Adb
 from .apk_downloader import ApkDownloader
+from .file_diff import is_sqlite_file
 from .fridump import Fridump
 from .fsmon import FSMon
 from .toolbox import Toolbox
@@ -45,6 +46,7 @@ class ActionQ:
     index = 0
     q = []
     finished = False
+    recently_installed_package = None  # Track the last installed package for spawn mode
 
     logger = getLogger(__name__)
     photographer = None
@@ -334,8 +336,9 @@ class ActionQ:
                     try:
                         while selected_idx < 1 or selected_idx > len(snapshots):
                             try:
-                                self.logger.info(
-                                    f"{Fore.CYAN}Select a snapshot to load ({Fore.YELLOW}1{Fore.CYAN}-{Fore.YELLOW}{len(snapshots)}{Fore.CYAN}): {Style.RESET_ALL}"
+                                click.echo(
+                                    f"{Fore.CYAN}Select a snapshot to load ({Fore.YELLOW}1{Fore.CYAN}-{Fore.YELLOW}{len(snapshots)}{Fore.CYAN}): {Style.RESET_ALL}",
+                                    nl=False,
                                 )
                                 char = click.getchar()
                                 if char.isdigit():
@@ -343,15 +346,15 @@ class ActionQ:
                                 else:
                                     selected_idx = 0  # Invalid input
                                 if selected_idx < 1 or selected_idx > len(snapshots):
-                                    self.logger.info(
+                                    click.echo(
                                         f"{Fore.RED}Please enter a number between {Fore.YELLOW}1{Fore.RED} and {Fore.YELLOW}{len(snapshots)}{Style.RESET_ALL}"
                                     )
                             except ValueError:
-                                self.logger.info(
+                                click.echo(
                                     f"{Fore.RED}Please enter a valid number{Style.RESET_ALL}"
                                 )
                     except KeyboardInterrupt:
-                        self.logger.info(
+                        click.echo(
                             f"\n{Fore.YELLOW}Snapshot selection cancelled by user.{Style.RESET_ALL}"
                         )
                         self.q.append("interactive")
@@ -362,19 +365,18 @@ class ActionQ:
                     # Add load snapshot command to the queue
                     Toolbox.load_snapshot(selected_snapshot.encode())
                 else:
-                    self.logger.warning(
-                        f"{Fore.RED}No snapshots available.{Style.RESET_ALL}"
-                    )
+                    self.logger.warning("No snapshots available.")
 
                 self.q.append("interactive")
                 return
             # Keys 1-8 for creating snapshots
             # Prompt for snapshot name
             try:
-                self.logger.info(
-                    f"{Fore.CYAN}Enter snapshot name (or press Enter for timestamp): {Style.RESET_ALL}"
+                click.echo(
+                    f"{Fore.CYAN}Enter snapshot name (or press Enter for timestamp): {Style.RESET_ALL}",
+                    nl=False,
                 )
-                snapshot_name = input()
+                snapshot_name = Toolbox.safe_input()
                 if not snapshot_name:
                     from datetime import datetime
 
@@ -383,7 +385,7 @@ class ActionQ:
                 # Create snapshot
                 Toolbox.create_snapshot(snapshot_name.encode())
             except KeyboardInterrupt:
-                self.logger.info(
+                click.echo(
                     f"\n{Fore.YELLOW}Snapshot creation cancelled by user.{Style.RESET_ALL}"
                 )
 
@@ -458,8 +460,8 @@ class ActionQ:
                 else:
                     self.logger.info(f"Pulled {spotlight_file} to {target_path}")
 
-                # For .db files, also pull WAL and journal files if they exist
-                if spotlight_file.endswith(".db") or True:
+                # For SQLite database files, also pull WAL and journal files if they exist
+                if is_sqlite_file(target_path):
                     # Pull the WAL file
                     wal_target = target_path + "-wal"
                     output, error = Adb.send_adb_command(
@@ -510,7 +512,7 @@ class ActionQ:
                     self.logger.info(
                         "Enter filename for screenshot (or press ENTER for timestamp):"
                     )
-                    filename = input().strip()
+                    filename = Toolbox.safe_input()
                     Toolbox.take_screenshot(filename if filename else None)
                 except KeyboardInterrupt:
                     self.logger.info("\nScreenshot cancelled")
@@ -528,7 +530,7 @@ class ActionQ:
                         self.logger.info(
                             "Enter filename for screen recording (or press ENTER for timestamp):"
                         )
-                        filename = input().strip()
+                        filename = Toolbox.safe_input()
 
                         # Start the recording
                         if Toolbox.start_screen_recording(
@@ -564,15 +566,24 @@ class ActionQ:
             case "n":  # New APK installation
                 try:
                     self.logger.info("Enter file path of APK or search term:")
-                    apk = input().strip()
+                    apk = Toolbox.safe_input()
+
+                    installed_package = None  # Track the installed package name
 
                     # Expand user path (~) and convert to absolute path
                     expanded_apk_path = os.path.abspath(os.path.expanduser(apk))
 
                     if os.path.isfile(expanded_apk_path):
                         self.logger.info(f"Found local APK file: {expanded_apk_path}")
-                        Adb.install_apk(expanded_apk_path)
-                        self.logger.info("APK installation completed successfully")
+                        installed_package = Adb.install_apk(expanded_apk_path)
+                        if installed_package:
+                            self.logger.info(
+                                f"APK installation completed successfully: {installed_package}"
+                            )
+                        else:
+                            self.logger.info(
+                                "APK installation completed, but package name could not be determined"
+                            )
                     else:
                         self.logger.info(
                             f"The path '{apk}' is not a valid file. Searching online for package."
@@ -580,6 +591,7 @@ class ActionQ:
                         try:
                             app_id = ApkDownloader().search_for_name(apk)
                             ApkDownloader().install_app_id(app_id)
+                            installed_package = app_id  # Online installers typically return package name
                             self.logger.info(
                                 "Online APK installation completed successfully"
                             )
@@ -590,6 +602,68 @@ class ActionQ:
                             self.logger.info(
                                 "Please check the search term or try a different APK"
                             )
+
+                    # Offer to set as spotlight spawn app
+                    if installed_package:
+                        # Store as recently installed for later use
+                        ActionQ.recently_installed_package = installed_package
+
+                        click.echo(
+                            f"\n{Fore.GREEN}✓ Successfully installed: {Fore.YELLOW}{installed_package}{Style.RESET_ALL}"
+                        )
+                        click.echo(
+                            f"\n{Fore.CYAN}Would you like to set this app for spawning?{Style.RESET_ALL}"
+                        )
+                        click.echo(
+                            f"{Fore.YELLOW}[y]{Style.RESET_ALL} = Yes, set as spotlight spawn app"
+                        )
+                        click.echo(
+                            f"{Fore.YELLOW}[n]{Style.RESET_ALL} = No, return to menu"
+                        )
+
+                        try:
+                            choice = click.getchar().lower()
+                            if choice == "y":
+                                Toolbox.set_spotlight_spawn_application(
+                                    installed_package
+                                )
+
+                                # Ask about auto-resume
+                                click.echo(
+                                    f"\n{Fore.CYAN}Auto-resume spawned app?{Style.RESET_ALL}"
+                                )
+                                click.echo(
+                                    f"{Fore.YELLOW}[y]{Style.RESET_ALL} = App starts immediately after spawn (recommended, default)"
+                                )
+                                click.echo(
+                                    f"{Fore.YELLOW}[n]{Style.RESET_ALL} = App stays paused, resume manually"
+                                )
+                                click.echo(
+                                    f"\n{Fore.GREEN}► Press y or n (Enter = yes):{Style.RESET_ALL} ",
+                                    nl=False,
+                                )
+
+                                resume_choice = click.getchar().lower()
+                                # Default to 'y' if Enter is pressed
+                                Toolbox.set_auto_resume_after_spawn(
+                                    resume_choice
+                                    != "n"  # Anything except 'n' means yes (including Enter)
+                                )
+
+                                resume_status = (
+                                    "enabled" if resume_choice != "n" else "disabled"
+                                )
+                                click.echo(
+                                    f"\n{Fore.GREEN}✓ Spotlight app configured:{Style.RESET_ALL}\n"
+                                    f"  Package: {Fore.YELLOW}{installed_package}{Style.RESET_ALL}\n"
+                                    f"  Mode: {Fore.CYAN}SPAWN{Style.RESET_ALL}\n"
+                                    f"  Auto-resume: {Fore.YELLOW}{resume_status}{Style.RESET_ALL}\n"
+                                )
+                            else:
+                                self.logger.info("Returning to menu...")
+                        except (KeyboardInterrupt, EOFError):
+                            self.logger.info("\nReturning to menu...")
+
                 except KeyboardInterrupt:
                     self.logger.info("\nOperation cancelled")
                 except Exception as e:
@@ -599,12 +673,76 @@ class ActionQ:
                     self.logger.info("Please check the file path or try again")
                 self.q.append("interactive")
             case "c":
+                # ATTACH MODE: Set currently focused app as spotlight (existing behavior)
                 Toolbox.set_spotlight_application(Adb.get_focused_app())
                 spotlight_application_name = Toolbox.get_spotlight_application()[0]
                 spotlight_application_pid = Adb.get_pid_for_package_name(
                     spotlight_application_name
                 )
                 Toolbox.set_spotlight_application_pid(spotlight_application_pid)
+                Toolbox.set_spawn_mode(False)  # Ensure attach mode
+                click.echo(
+                    f"{Fore.GREEN}Spotlight app set in ATTACH mode: {spotlight_application_name}{Style.RESET_ALL}"
+                )
+                self.q.append("interactive")
+            case "C":
+                # SPAWN MODE: Select app to spawn with fuzzy search
+                try:
+                    click.echo(
+                        f"\n{Fore.CYAN}=== Spawn Mode Selection ==={Style.RESET_ALL}"
+                    )
+                    click.echo(
+                        "Select an application to spawn when using Frida-based tools.\n"
+                        "The app will be launched fresh with hooks active from the start.\n"
+                    )
+
+                    # Use fuzzy search to select app (with recently installed as default)
+                    selected_package = Toolbox.select_app_with_fuzzy_search(
+                        recently_installed_package=ActionQ.recently_installed_package
+                    )
+
+                    if selected_package:
+                        Toolbox.set_spotlight_spawn_application(selected_package)
+
+                        # Ask about auto-resume preference with clear prompt
+                        click.echo(
+                            f"\n{Fore.CYAN}=== Auto-Resume Configuration ==={Style.RESET_ALL}"
+                        )
+                        click.echo(
+                            f"{Fore.YELLOW}[y]{Style.RESET_ALL} = App starts immediately after spawn (recommended, default)"
+                        )
+                        click.echo(
+                            f"{Fore.YELLOW}[n]{Style.RESET_ALL} = App stays paused, resume manually"
+                        )
+                        click.echo(
+                            f"\n{Fore.GREEN}► Press y or n (Enter = yes):{Style.RESET_ALL} ",
+                            nl=False,
+                        )
+
+                        resume_choice = click.getchar().lower()
+                        print(
+                            f"{Fore.YELLOW}{resume_choice}{Style.RESET_ALL}"
+                        )  # Echo the choice
+                        # Default to 'y' if Enter is pressed
+                        Toolbox.set_auto_resume_after_spawn(resume_choice != "n")
+
+                        resume_status = (
+                            "enabled" if resume_choice != "n" else "disabled"
+                        )
+                        click.echo(
+                            f"\n{Fore.GREEN}✓ Spotlight app configured:{Style.RESET_ALL}\n"
+                            f"  Package: {Fore.YELLOW}{selected_package}{Style.RESET_ALL}\n"
+                            f"  Mode: {Fore.CYAN}SPAWN{Style.RESET_ALL}\n"
+                            f"  Auto-resume: {Fore.YELLOW}{resume_status}{Style.RESET_ALL}\n"
+                        )
+                    else:
+                        self.logger.info("Spawn mode selection cancelled")
+
+                except KeyboardInterrupt:
+                    self.logger.info("\nSpawn mode selection cancelled by user")
+                except Exception as e:
+                    self.logger.error(f"Error setting spawn mode: {e}")
+
                 self.q.append("interactive")
             case "a":
                 try:
@@ -619,146 +757,202 @@ class ActionQ:
                 # Toolbox.submit_other_data("asam", asam.return_data())
                 self.q.append("interactive")
             case "m":
-                check_frida = self.check_frida_and_spotlight()
-                if not check_frida:
-                    self.q.append("interactive")
-                    return
-
-                spotlight_application_pid, spotlight_application_name = check_frida
-
-                self.logger.info(
-                    "Now the dexray-intercept output follows. End with CTRC-C"
-                )
-                if self.malwaremonitor == None:
-                    self.malwaremonitor = MalwareMonitor(
-                        path_filters=Toolbox.get_spotlight_files()
-                    )
-                self.malwaremonitor.gather()
-
-                if self.malwaremonitor.has_new_results():
-                    Toolbox.submit_other_data(
-                        "Dexray Intercept",
-                        self.malwaremonitor.return_data(),
-                    )
-
                 try:
+                    check_frida = self.check_frida_and_spotlight()
+                    if not check_frida:
+                        self.q.append("interactive")
+                        return
+
+                    spotlight_application_pid, spotlight_application_name = check_frida
+
+                    self.logger.info(
+                        "Now the dexray-intercept output follows. End with CTRL-C"
+                    )
+                    if self.malwaremonitor == None:
+                        # Get debug mode from Toolbox args (set by CLI --debug flag)
+                        debug_mode = getattr(Toolbox.args, "debug", False)
+                        self.malwaremonitor = MalwareMonitor(
+                            path_filters=Toolbox.get_spotlight_files(),
+                            debug_mode=debug_mode,
+                        )
+                    self.malwaremonitor.gather()
+
+                    if self.malwaremonitor.has_new_results():
+                        Toolbox.submit_other_data(
+                            "Dexray Intercept",
+                            self.malwaremonitor.return_data(),
+                        )
+
                     self.logger.info(
                         "Malware monitoring in progress... Press CTRL+C to stop"
                     )
                     while True:
                         time.sleep(0.5)  # Sleep to reduce CPU usage
                 except KeyboardInterrupt:
-                    self.logger.info("CTRL-C detected. Stopping malware monitoring.")
-                    self.malwaremonitor.gather()
+                    self.logger.info("\nCTRL-C detected. Stopping malware monitoring.")
+                    if self.malwaremonitor:
+                        self.malwaremonitor.gather()
                     # Reset spotlight app info as the app may have been closed
                     Toolbox.reset_spotlight_application()
                 self.q.append("interactive")
             case "h":
                 try:
-                    check_frida = self.check_frida_and_spotlight()
-                    if not check_frida:
+                    # Check Frida is running
+                    if not Toolbox.frida_manager.is_frida_server_running():
+                        self.logger.warning(
+                            "No frida server is running. Please start or install it first."
+                        )
                         self.q.append("interactive")
                         return
 
-                    spotlight_application_pid, spotlight_application_name = check_frida
-                    # self.logger.info("Keys will be written to keylog.log")
-                    self.logger.info("Now fritap output follows. End with CTRC-C")
-                    fritap = FriTap(spotlight_application_pid)
+                    # FriTap now handles both spawn/attach internally
+                    self.logger.info("Now fritap output follows. End with CTRL-C")
+                    fritap = FriTap()  # No args needed, uses unified session getter
                     fritap.start()
 
-                    try:
-                        self.logger.info(
-                            "friTap monitoring in progress... Press CTRL+C to stop"
-                        )
-                        while True:
-                            time.sleep(0.5)  # Sleep to reduce CPU usage
-                    except KeyboardInterrupt:
-                        self.logger.info("CTRL-C detected. Stopping FriTap monitoring.")
+                    self.logger.info(
+                        "friTap monitoring in progress... Press CTRL+C to stop"
+                    )
+                    while True:
+                        time.sleep(0.5)  # Sleep to reduce CPU usage
+                except KeyboardInterrupt:
+                    self.logger.info("\nCTRL-C detected. Stopping FriTap monitoring.")
+                    if "fritap" in locals():
                         fritap.stop()
                         self.logger.info("FriTap monitoring stopped.")
-                        # Reset spotlight app info as the app may have been closed
+                    # Reset spotlight app info if spawned
+                    if Toolbox.is_spawn_mode():
                         Toolbox.reset_spotlight_application()
-                except KeyboardInterrupt:
-                    self.logger.info("\nOperation cancelled")
                 except Exception as e:
                     self.logger.error(f"Error during friTap monitoring: {e!s}")
 
                 self.q.append("interactive")
             case "d":
                 try:
-                    check_frida = self.check_frida_and_spotlight()
-                    if not check_frida:
-                        return
-
-                    spotlight_application_pid, spotlight_application_name = check_frida
-
-                    if spotlight_application_pid:
-                        Fridump.dump_memory(
-                            spotlight_application_pid, spotlight_application_name
+                    # Check Frida is running
+                    if not Toolbox.frida_manager.is_frida_server_running():
+                        self.logger.warning(
+                            "No frida server is running. Please start or install it first."
                         )
-                    else:
-                        self.logger.warning("Spotlight app has to be set first.")
                         self.q.append("interactive")
                         return
+
+                    # Fridump now handles both spawn/attach internally
+                    Fridump.dump_memory()  # Uses unified session getter
+
                 except KeyboardInterrupt:
                     self.logger.info("\nOperation cancelled")
+                except Exception as e:
+                    self.logger.error(f"Error during memory dump: {e}")
                 self.q.append("interactive")
 
             case "o":
                 try:
                     FSMon.check_and_install_fsmon()
 
+                    # Get spotlight info (works with both spawn and attach modes)
                     spotlight_data_path = Toolbox.get_spotlighted_app_data_path()
-                    spotlight_application_pid = Toolbox.get_spotlight_application_pid()
                     process = None
 
-                    if spotlight_application_pid:
-                        self.logger.info(
-                            f"Press ENTER to monitor spotlight app (PID: {spotlight_application_pid}) or enter a path to monitor:"
-                        )
-                        user_input = input().strip()
-
-                        if user_input:
-                            process = FSMon.run_fsmon_by_path(user_input)
-                        else:
-                            process = FSMon.run_fsmon_by_pid(spotlight_application_pid)
-                    else:
-                        self.logger.info(
-                            "No spotlight app is set. Enter a path to monitor:"
-                        )
-                        user_input = input().strip()
-
-                        if user_input:
-                            process = FSMon.run_fsmon_by_path(user_input)
-                        else:
-                            self.logger.warning(
-                                "No path specified and no spotlight app available."
+                    # Try to get PID from current spotlight settings
+                    if Toolbox.is_spawn_mode():
+                        # In spawn mode, app may not be running yet
+                        spawn_app = Toolbox.get_spotlight_spawn_application()
+                        if spawn_app:
+                            click.echo(
+                                f"{Fore.YELLOW}Spawn mode active for {spawn_app}.{Style.RESET_ALL}"
                             )
-                            self.q.append("interactive")
-                            return
+                            click.echo(
+                                "FSMon requires a running process. Options:\n"
+                                "  1. Press ENTER to monitor app's data directory\n"
+                                "  2. Enter a custom path to monitor"
+                            )
+                            user_input = Toolbox.safe_input()
+
+                            if user_input:
+                                process = FSMon.run_fsmon_by_path(user_input)
+                            elif spotlight_data_path:
+                                process = FSMon.run_fsmon_by_path(spotlight_data_path)
+                            else:
+                                self.logger.warning("No valid path available.")
+                                self.q.append("interactive")
+                                return
+                        else:
+                            self.logger.info(
+                                "No spotlight app set. Enter a path to monitor:"
+                            )
+                            user_input = Toolbox.safe_input()
+                            if user_input:
+                                process = FSMon.run_fsmon_by_path(user_input)
+                            else:
+                                self.logger.warning("No path specified.")
+                                self.q.append("interactive")
+                                return
+                    else:
+                        # Attach mode or no mode - try to get PID
+                        spotlight_application_pid = (
+                            Toolbox.get_spotlight_application_pid()
+                        )
+
+                        if spotlight_application_pid:
+                            mode_str = (
+                                f"{Fore.GREEN}[ATTACH MODE]{Style.RESET_ALL}"
+                                if Toolbox.get_spotlight_application()
+                                else ""
+                            )
+                            click.echo(
+                                f"Press ENTER to monitor spotlight app {mode_str} (PID: {spotlight_application_pid}) or enter a path to monitor:"
+                            )
+                            user_input = Toolbox.safe_input()
+
+                            if user_input:
+                                process = FSMon.run_fsmon_by_path(user_input)
+                            else:
+                                process = FSMon.run_fsmon_by_pid(
+                                    spotlight_application_pid
+                                )
+                        else:
+                            self.logger.info(
+                                "No spotlight app is set. Enter a path to monitor:"
+                            )
+                            user_input = Toolbox.safe_input()
+
+                            if user_input:
+                                process = FSMon.run_fsmon_by_path(user_input)
+                            else:
+                                self.logger.warning(
+                                    "No path specified and no spotlight app available."
+                                )
+                                self.q.append("interactive")
+                                return
 
                     if process is None:
                         self.logger.warning("Failed to start FSMon monitoring.")
                         self.q.append("interactive")
                         return
 
-                    if user_input:
-                        self.logger.info(
-                            f"Now fsmon output for path {user_input} follows. End with CTRL-C"
-                        )
+                    # Determine what we're monitoring for log message
+                    if "user_input" in locals() and user_input:
+                        monitor_target = f"path {user_input}"
+                    elif (
+                        "spotlight_application_pid" in locals()
+                        and spotlight_application_pid
+                    ):
+                        monitor_target = f"PID {spotlight_application_pid}"
                     else:
-                        self.logger.info(
-                            f"Now fsmon output for PID {spotlight_application_pid} follows. End with CTRL-C"
-                        )
+                        monitor_target = f"path {spotlight_data_path}"
 
-                    try:
-                        while True:
-                            pass
-                    except KeyboardInterrupt:
-                        process.terminate()
-                        self.logger.info("CTRL-C detected. Exiting fsmon loop.")
+                    self.logger.info(
+                        f"Now fsmon output for {monitor_target} follows. End with CTRL-C"
+                    )
+
+                    while True:
+                        pass
                 except KeyboardInterrupt:
-                    self.logger.info("\nOperation cancelled")
+                    self.logger.info("\nCTRL-C detected. Stopping FSMon monitoring.")
+                    if "process" in locals() and process is not None:
+                        process.terminate()
+                        self.logger.info("FSMon process terminated.")
                 self.q.append("interactive")
 
             case "e":
@@ -788,7 +982,7 @@ class ActionQ:
                     self.logger.info(
                         "Enter the file path to add as a spotlight file (or press ENTER to skip):"
                     )
-                    file_path = input().strip()
+                    file_path = Toolbox.safe_input()
                     if file_path:
                         if file_path.endswith("-wal") or file_path.endswith("-journal"):
                             self.logger.warning(
@@ -816,7 +1010,7 @@ class ActionQ:
                         self.logger.info(
                             "Enter the file path to remove from spotlight files:"
                         )
-                        file_path = input().strip()
+                        file_path = Toolbox.safe_input()
                         Toolbox.remove_spotlight_file(file_path)
                 except KeyboardInterrupt:
                     self.logger.info("\nOperation cancelled")
@@ -826,7 +1020,7 @@ class ActionQ:
                     self.logger.info(
                         "Enter a short description of the action performed (or press ENTER to skip):"
                     )
-                    description = input().strip()
+                    description = Toolbox.safe_input()
 
                     success = Toolbox.pull_spotlight_files(
                         description=description if description else None
@@ -847,33 +1041,67 @@ class ActionQ:
 
             case "b":
                 try:
-                    check_frida = self.check_frida_and_spotlight()
-                    if not check_frida:
+                    # Check Frida is running
+                    if not Toolbox.frida_manager.is_frida_server_running():
+                        self.logger.warning(
+                            "No frida server is running. Please start or install it first."
+                        )
+                        self.q.append("interactive")
                         return
 
-                    spotlight_application_pid, spotlight_application_name = check_frida
-
-                    self.logger.info(
-                        f"Launching objection interactive shell for {spotlight_application_name}"
-                    )
-
+                    # Get session info using unified getter
                     try:
-                        cmd = [
-                            "objection",
-                            "--gadget",
-                            str(spotlight_application_pid),
-                            "explore",
-                        ]
+                        session, mode, app_info = (
+                            Toolbox.get_frida_session_for_spotlight()
+                        )
+                        package_name = app_info["package_name"]
+                        pid = app_info["pid"]
+
+                        self.logger.info(
+                            f"Launching objection interactive shell in {mode.upper()} mode for {package_name}"
+                        )
+
+                        # Build objection command based on mode
+                        if mode == "spawn":
+                            # For spawn mode, objection can handle spawning itself
+                            cmd = [
+                                "objection",
+                                "-g",
+                                package_name,
+                                "explore",
+                                "--startup-command",
+                                "android hooking watch class_method *.*",  # Example startup hook
+                            ]
+                            self.logger.info(
+                                f"Note: Objection will spawn a fresh instance of {package_name}"
+                            )
+                        else:
+                            # Attach mode (existing behavior)
+                            cmd = [
+                                "objection",
+                                "--gadget",
+                                str(pid),
+                                "explore",
+                            ]
+
                         self.logger.info(f"Running command: {' '.join(cmd)}")
 
                         process = subprocess.Popen(cmd)  # nosec S603 # Launching objection security tool
                         process.communicate()
 
                         self.logger.info("Objection session ended")
+
+                        # Reset spotlight if spawned
+                        if mode == "spawn":
+                            Toolbox.reset_spotlight_application()
+
                     except Exception as e:
-                        self.logger.error(f"Error launching objection: {e!s}")
+                        self.logger.error(f"Error getting spotlight session: {e}")
+
                 except KeyboardInterrupt:
                     self.logger.info("\nOperation cancelled")
+                except Exception as e:
+                    self.logger.error(f"Error launching objection: {e!s}")
                 self.q.append("interactive")
             case "w":
                 try:
@@ -893,7 +1121,7 @@ class ActionQ:
                         self.logger.info(
                             "Enter path for the network capture file (or press ENTER for default):"
                         )
-                        user_path = input().strip()
+                        user_path = Toolbox.safe_input()
 
                         # Generate a default filename with timestamp if none provided
                         if not user_path:
@@ -956,7 +1184,7 @@ class ActionQ:
     def check_frida_and_spotlight(self):
         """Checks if the frida server is running and if a spotlight application is set.
         Appends 'interactive' and returns None if the check fails.
-        Returns (PID, app_name) if successful.
+        Returns (PID, app_name) if successful (for attach mode) or (None, package_name) for spawn mode.
         """
         # Check if the frida server is running
         if not Toolbox.frida_manager.is_frida_server_running():
@@ -966,6 +1194,19 @@ class ActionQ:
             self.q.append("interactive")
             return None
 
+        # Check for spawn mode first
+        if Toolbox.is_spawn_mode():
+            spawn_app = Toolbox.get_spotlight_spawn_application()
+            if spawn_app:
+                # Spawn mode is set with an app
+                return (None, spawn_app)
+            self.logger.warning(
+                "Spawn mode is enabled but no spawn application is set."
+            )
+            self.q.append("interactive")
+            return None
+
+        # Check for attach mode
         spotlight_application = Toolbox.get_spotlight_application()
 
         if not spotlight_application:
