@@ -8,9 +8,26 @@ import os
 import re
 import shutil
 import subprocess
+import sys
 import threading
 import time
 
+# Platform-specific imports for stdin flushing
+try:
+    import fcntl
+    import termios
+
+    TERMIOS_AVAILABLE = True
+except ImportError:
+    TERMIOS_AVAILABLE = False
+
+try:
+    import msvcrt
+
+    MSVCRT_AVAILABLE = True
+except ImportError:
+    MSVCRT_AVAILABLE = False
+
 # Third-party imports
 import click
 import dateutil.parser as dp
@@ -23,6 +40,7 @@ from colorama import Fore, Style
 from .adb import Adb
 from .CustomLoggerFormatter import CustomFormatter
 from .emulator import Emulator
+from .file_diff import is_sqlite_file
 
 
 class Toolbox:
@@ -56,6 +74,11 @@ class Toolbox:
     _spotlight_pull_two = None
     _screen_recording_running = False
 
+    # Spawn mode variables
+    _spawn_mode = False
+    _spotlight_spawn_application = None
+    _auto_resume_after_spawn = True  # Auto-resume by default
+
     # replace these with your own values
     # TODO: Shouldn't be hardcoded
     device_name = "Pixel_6_Pro_API_31"
@@ -64,6 +87,54 @@ class Toolbox:
     def __new__(cls):
         raise TypeError("This is a static class and cannot be instantiated.")
 
+    @classmethod
+    def safe_input(cls, prompt: str = "") -> str:
+        """Safely read input from stdin with buffer flushing to prevent input swallowing issues.
+
+        This method addresses buffering problems that occur when multiple interactive programs
+        (e.g., Claude Code, then sandroid) run in the same terminal session. It flushes any
+        pending stdin input before reading, which prevents leftover buffered data from being
+        consumed or terminal state issues from causing input to be lost.
+
+        Args:
+            prompt: Optional prompt string to display before reading input
+
+        Returns:
+            The user's input as a string (stripped of leading/trailing whitespace)
+
+        Note:
+            Works cross-platform (Linux, macOS, Windows) and handles non-TTY cases gracefully.
+        """
+        # Only attempt flushing if stdin is a TTY (interactive terminal)
+        if sys.stdin.isatty():
+            try:
+                # Unix-like systems (Linux, macOS)
+                if TERMIOS_AVAILABLE:
+                    # Flush the input buffer
+                    termios.tcflush(sys.stdin, termios.TCIFLUSH)
+
+                # Windows systems
+                elif MSVCRT_AVAILABLE:
+                    # Flush Windows console input buffer
+                    while msvcrt.kbhit():
+                        msvcrt.getch()
+
+            except Exception as e:
+                # Log but don't fail - just proceed with regular input
+                if cls.logger:
+                    cls.logger.debug(f"Could not flush stdin buffer: {e}")
+
+        # Display prompt if provided
+        if prompt:
+            print(prompt, end="", flush=True)
+
+        # Read input normally
+        try:
+            return input().strip()
+        except EOFError:
+            # Handle EOF gracefully (e.g., when input is redirected)
+            return ""
+
     @classmethod
     def init(cls):
         """Initializes the Toolbox class by parsing command-line arguments and setting up the logger and Frida manager."""
@@ -181,6 +252,12 @@ class Toolbox:
             default=False,
             help="Use AI to summarize the action and generate a report",
         )
+        parser.add_argument(
+            "--debug",
+            action="store_true",
+            default=False,
+            help="Enable debug/verbose mode (shows detailed hook installation and internal messages from dexray-intercept)",
+        )
 
         cls.args = parser.parse_args()
         if cls.logger is None:
@@ -260,7 +337,7 @@ class Toolbox:
                     while selected_idx < 1 or selected_idx > len(available_emulators):
                         try:
                             selected_idx = int(
-                                input(
+                                cls.safe_input(
                                     f"\n{Fore.CYAN}Select an emulator to start ({Fore.YELLOW}1{Fore.CYAN}-{Fore.YELLOW}{len(available_emulators)}{Fore.CYAN}): {Style.RESET_ALL}"
                                 )
                             )
@@ -284,13 +361,11 @@ class Toolbox:
                 selected_emulator = available_emulators[selected_idx - 1]
                 # Update the device name with selected emulator
                 cls.device_name = selected_emulator
-                cls.logger.info(
-                    f"Starting emulator {Fore.GREEN}{selected_emulator}{Style.RESET_ALL}..."
-                )
+                cls.logger.info(f"Starting emulator {selected_emulator}...")
 
                 if Emulator.start_avd(selected_emulator):
                     cls.logger.info(
-                        f"Emulator '{Fore.GREEN}{selected_emulator}{Style.RESET_ALL}' started successfully. Continuing setup..."
+                        f"Emulator '{selected_emulator}' started successfully. Continuing setup..."
                     )
                     # Re-check connection after starting
                     stdout_check, stderr_check = Adb.send_adb_command("shell ls /data")
@@ -412,9 +487,7 @@ class Toolbox:
         :param name: The name of the snapshot.
         :type name: str
         """
-        cls.logger.info(
-            f"Creating snapshot: {Fore.GREEN}{name.decode('utf-8')}{Style.RESET_ALL}"
-        )
+        cls.logger.info(f"Creating snapshot: {name.decode('utf-8')}")
         Adb.send_telnet_command(b"avd snapshot save " + name)
 
     @classmethod
@@ -427,9 +500,7 @@ class Toolbox:
         :param name: The name of the snapshot.
         :type name: str
         """
-        cls.logger.info(
-            f"Loading snapshot: {Fore.GREEN}{name.decode('utf-8')}{Style.RESET_ALL}"
-        )
+        cls.logger.info(f"Loading snapshot: {name.decode('utf-8')}")
         Adb.send_telnet_command(b"avd snapshot load " + name)
         time.sleep(2)
 
@@ -546,12 +617,15 @@ class Toolbox:
                     cls.add_to_shadow_ts_list(
                         currentDir, filename, secondsTimestamp, fetch_all=fetch_all
                     )
-                    if filename.endswith(
-                        ".db-wal"
-                    ):  # Make sure db files that use write ahead logging are also added to list
+                    # Make sure parent db files are added when WAL or journal files change
+                    if filename.endswith("-wal"):
                         changedFiles.update(
                             {currentDir + filename[0:-4]: secondsTimestamp}
                         )
+                    elif filename.endswith("-journal"):
+                        changedFiles.update(
+                            {currentDir + filename[0:-8]: secondsTimestamp}
+                        )
 
         returnThis = {}
         for changedFile, changedTime in reversed(changedFiles.items()):
@@ -704,13 +778,441 @@ class Toolbox:
         """
         cls._spotlight_application = None
         cls._spotlight_application_pid = None
+        cls._spawn_mode = False
+        cls._spotlight_spawn_application = None
         cls.logger.info("Spotlight application information has been reset.")
 
+    @classmethod
+    def set_spawn_mode(cls, enabled):
+        """Sets whether spawn mode is enabled.
+
+        :param enabled: True to enable spawn mode, False for attach mode.
+        :type enabled: bool
+        """
+        cls._spawn_mode = enabled
+        mode_str = "SPAWN" if enabled else "ATTACH"
+        cls.logger.info(f"Spotlight mode set to: {mode_str}")
+
+    @classmethod
+    def is_spawn_mode(cls):
+        """Returns whether spawn mode is currently enabled.
+
+        :returns: True if spawn mode is enabled, False otherwise.
+        :rtype: bool
+        """
+        return cls._spawn_mode
+
+    @classmethod
+    def set_spotlight_spawn_application(cls, package_name):
+        """Sets the application to be spawned when using Frida-based tools.
+
+        :param package_name: The package name of the app to spawn.
+        :type package_name: str
+        """
+        cls._spotlight_spawn_application = package_name
+        cls._spawn_mode = True
+        cls.logger.info(f"Spotlight spawn application set to: {package_name}")
+
+    @classmethod
+    def get_spotlight_spawn_application(cls):
+        """Returns the package name of the app to be spawned.
+
+        :returns: The package name of the spawn app, or None if not set.
+        :rtype: str or None
+        """
+        return cls._spotlight_spawn_application
+
+    @classmethod
+    def set_auto_resume_after_spawn(cls, enabled):
+        """Sets whether spawned apps should be auto-resumed.
+
+        :param enabled: True to auto-resume, False to leave paused.
+        :type enabled: bool
+        """
+        cls._auto_resume_after_spawn = enabled
+        cls.logger.info(f"Auto-resume after spawn: {enabled}")
+
+    @classmethod
+    def get_auto_resume_after_spawn(cls):
+        """Returns whether auto-resume after spawn is enabled.
+
+        :returns: True if auto-resume is enabled, False otherwise.
+        :rtype: bool
+        """
+        return cls._auto_resume_after_spawn
+
+    @classmethod
+    def resume_spawned_process_after_hooks(cls, device, pid):
+        """Resume a spawned process after hooks have been installed.
+
+        This includes the required 1-second sleep to prevent Java.perform from silently failing.
+
+        :param device: Frida device object
+        :type device: frida.core.Device
+        :param pid: Process ID to resume
+        :type pid: int
+        """
+        import time
+
+        if cls._auto_resume_after_spawn:
+            cls.logger.debug(f"Resuming spawned process {pid} after hook installation")
+            device.resume(pid)
+            time.sleep(1)  # CRITICAL: Prevents Java.perform from silently failing
+            cls.logger.debug("Process resumed and stabilized")
+        else:
+            cls.logger.info(
+                f"Process {pid} remains PAUSED (auto-resume disabled). "
+                "Resume manually when ready."
+            )
+
+    @classmethod
+    def get_frida_session_for_spotlight(cls):
+        """Returns appropriate Frida session based on current mode (spawn/attach).
+
+        This is the unified abstraction layer for all Frida-based tools.
+
+        :returns: A tuple of (session, mode, app_info) where:
+            - session: Frida session object
+            - mode: "spawn" or "attach"
+            - app_info: dict with package_name, pid, mode, etc.
+        :rtype: tuple
+        :raises: Exception if Frida setup fails
+        """
+        import frida
+
+        try:
+            device = frida.get_usb_device()
+
+            if cls._spawn_mode and cls._spotlight_spawn_application:
+                # SPAWN MODE
+                cls.logger.info(
+                    f"Spawning application: {cls._spotlight_spawn_application}"
+                )
+
+                # Spawn the application (starts paused)
+                pid = device.spawn([cls._spotlight_spawn_application])
+                cls.logger.debug(f"Spawned process with PID: {pid}")
+
+                # Attach to the spawned process
+                session = device.attach(pid)
+                cls.logger.debug("Attached to spawned process")
+
+                # Don't resume yet - let the caller resume AFTER installing hooks
+                cls.logger.debug(
+                    f"Process spawned and attached but PAUSED. "
+                    f"Will be resumed after hooks are installed (auto-resume: {cls._auto_resume_after_spawn})"
+                )
+
+                app_info = {
+                    "package_name": cls._spotlight_spawn_application,
+                    "pid": pid,
+                    "mode": "spawn",
+                    "device": device,
+                }
+
+                cls.logger.info(
+                    f"Successfully spawned and attached to {cls._spotlight_spawn_application} "
+                    f"(PID: {pid})"
+                )
+
+                return session, "spawn", app_info
+
+            # ATTACH MODE (existing behavior)
+            if not cls._spotlight_application:
+                raise ValueError(
+                    "No spotlight application set. Press 'c' to set current app or 'C' to select spawn app."
+                )
+
+            package_name = cls._spotlight_application[0]
+            cls.logger.info(f"Attaching to running application: {package_name}")
+
+            # Get PID if not already set
+            if not cls._spotlight_application_pid:
+                from .adb import Adb
+
+                pid = Adb.get_pid_for_package_name(package_name)
+                if not pid:
+                    raise ValueError(
+                        f"Application {package_name} is not running. "
+                        f"Start it first or use spawn mode (Shift+C)."
+                    )
+                cls._spotlight_application_pid = pid
+            else:
+                pid = cls._spotlight_application_pid
+
+            # Attach to running process
+            session = device.attach(package_name)
+            cls.logger.debug(f"Attached to running process (PID: {pid})")
+
+            app_info = {
+                "package_name": package_name,
+                "pid": pid,
+                "mode": "attach",
+                "device": device,
+            }
+
+            cls.logger.info(f"Successfully attached to {package_name} (PID: {pid})")
+
+            return session, "attach", app_info
+
+        except frida.ProcessNotFoundError as e:
+            cls.logger.error(f"Process not found: {e}")
+            raise
+        except frida.ServerNotRunningError:
+            cls.logger.error("Frida server is not running. Press 'f' to start it.")
+            raise
+        except Exception as e:
+            error_msg = str(e).lower()
+
+            # Handle specific "front-door activity" error in spawn mode
+            if "front-door" in error_msg or "unable to find" in error_msg:
+                cls.logger.error(f"Error setting up Frida session: {e}")
+                cls.logger.error("")
+                cls.logger.error("This error typically occurs when:")
+                cls.logger.error("  1. The app has no launchable main activity")
+                cls.logger.error("  2. The package name is incorrect")
+                cls.logger.error("  3. The app cannot be launched directly")
+                cls.logger.error("")
+                cls.logger.error("Suggestions:")
+                cls.logger.error("  - Verify the package name is correct")
+                cls.logger.error(
+                    "  - Try using ATTACH mode instead (press 'c' after launching the app manually)"
+                )
+                cls.logger.error("  - Check if the app appears in the launcher")
+                cls.logger.error("  - For system services, use attach mode only")
+            else:
+                cls.logger.error(f"Error setting up Frida session: {e}")
+            raise
+
+    @classmethod
+    def select_app_with_fuzzy_search(cls, recently_installed_package=None):
+        """Interactive app selection with fuzzy search capability.
+
+        Displays user-installed apps by default and allows user to filter them with fuzzy search.
+        Offers option to show all apps (including system apps).
+
+        :param recently_installed_package: Package name of a recently installed app to highlight/suggest.
+        :type recently_installed_package: str or None
+        :returns: Selected package name, or None if cancelled.
+        :rtype: str or None
+        """
+        from .adb import Adb
+
+        try:
+            # Try to import fuzzy search library
+            try:
+                from thefuzz import fuzz, process
+
+                has_fuzzy = True
+            except ImportError:
+                cls.logger.warning(
+                    "thefuzz library not installed. Install with: pip install thefuzz"
+                )
+                cls.logger.info("Falling back to simple numbered selection")
+                has_fuzzy = False
+
+            # Suggest recently installed app first if provided
+            if recently_installed_package:
+                click.echo(
+                    f"\n{Fore.CYAN}=== Recently Installed App ==={Style.RESET_ALL}"
+                )
+                click.echo(
+                    f"{Fore.YELLOW}[0]{Style.RESET_ALL} {Fore.GREEN}{recently_installed_package}{Style.RESET_ALL} "
+                    f"{Fore.CYAN}(Just installed){Style.RESET_ALL}"
+                )
+                click.echo(
+                    f"\n{Fore.YELLOW}Press 0 to use this app, or press ENTER to see all apps:{Style.RESET_ALL}"
+                )
+
+                try:
+                    char = click.getchar()
+                    if char == "0":
+                        cls.logger.info(
+                            f"Selected recently installed app: {recently_installed_package}"
+                        )
+                        return recently_installed_package
+                except (KeyboardInterrupt, EOFError):
+                    pass  # Continue to app list
+
+            # Ask if user wants to see all apps or just user-installed
+            click.echo(f"\n{Fore.CYAN}=== App Filter ==={Style.RESET_ALL}")
+            click.echo(
+                f"{Fore.YELLOW}[1]{Style.RESET_ALL} Show only user-installed apps (recommended)"
+            )
+            click.echo(
+                f"{Fore.YELLOW}[2]{Style.RESET_ALL} Show all apps (including system apps)"
+            )
+            click.echo(
+                f"\n{Fore.YELLOW}Select filter (press 1 or 2, default is 1):{Style.RESET_ALL}"
+            )
+
+            try:
+                char = click.getchar()
+                show_all = char == "2"
+            except (KeyboardInterrupt, EOFError):
+                show_all = False  # Default to user-installed only
+
+            # Get installed packages based on filter
+            cls.logger.info("Fetching installed applications...")
+            packages = Adb.get_installed_packages(user_only=not show_all)
+
+            if not packages:
+                cls.logger.error("No packages found on device")
+                return None
+
+            # Sort by install date (newest first), then by package name
+            packages.sort(
+                key=lambda x: (x.get("install_date") or "", x["package_name"]),
+                reverse=True,
+            )
+
+            # Start with all packages (show apps first, then allow filtering)
+            filtered_packages = packages
+
+            # Display filtered packages
+            app_type = "User-Installed" if not show_all else "All"
+            click.echo(
+                f"\n{Fore.CYAN}=== {app_type} Applications ({len(filtered_packages)}) ==={Style.RESET_ALL}"
+            )
+
+            for idx, pkg in enumerate(filtered_packages, 1):
+                install_date = pkg.get("install_date", "Unknown")
+                # Truncate long package names for display
+                pkg_name = pkg["package_name"]
+                if len(pkg_name) > 50:
+                    pkg_name = pkg_name[:47] + "..."
+
+                # Show app type indicator if showing all apps
+                type_indicator = ""
+                if show_all and pkg.get("is_user_app", False):
+                    type_indicator = f" {Fore.BLUE}[USER]{Style.RESET_ALL}"
+
+                print(
+                    f"{Fore.YELLOW}{idx:3d}.{Style.RESET_ALL} "
+                    f"{Fore.GREEN}{pkg_name:50s}{Style.RESET_ALL}"
+                    f"{type_indicator} "
+                    f"{Fore.CYAN}[{install_date}]{Style.RESET_ALL}"
+                )
+
+                # Add pagination for long lists
+                if idx % 20 == 0 and idx < len(filtered_packages):
+                    response = cls.safe_input(
+                        f"\n{Fore.YELLOW}Press ENTER to see more, or type a number to select: {Style.RESET_ALL}"
+                    )
+                    if response.isdigit():
+                        selected_idx = int(response)
+                        if 1 <= selected_idx <= len(filtered_packages):
+                            return filtered_packages[selected_idx - 1]["package_name"]
+
+            # Get user selection (with optional fuzzy filtering)
+            while True:
+                try:
+                    # Build prompt based on fuzzy search availability
+                    if has_fuzzy and filtered_packages == packages:
+                        prompt = f"\n{Fore.YELLOW}Enter number (1-{len(filtered_packages)}), 'f' to filter, or 'q' to cancel: {Style.RESET_ALL}"
+                    else:
+                        prompt = f"\n{Fore.YELLOW}Enter number (1-{len(filtered_packages)}) or 'q' to cancel: {Style.RESET_ALL}"
+
+                    selection_input = cls.safe_input(prompt)
+
+                    if selection_input.lower() == "q":
+                        cls.logger.info("Selection cancelled")
+                        return None
+
+                    # Fuzzy search filter option
+                    if selection_input.lower() == "f" and has_fuzzy:
+                        click.echo(
+                            f"\n{Fore.CYAN}=== Fuzzy Search Filter ==={Style.RESET_ALL}"
+                        )
+                        search_term = cls.safe_input(
+                            f"{Fore.YELLOW}Enter search term (or press ENTER to show all): {Style.RESET_ALL}"
+                        )
+
+                        if search_term:
+                            # Perform fuzzy matching
+                            package_names = [p["package_name"] for p in packages]
+                            matches = process.extract(
+                                search_term,
+                                package_names,
+                                scorer=fuzz.partial_ratio,
+                                limit=20,
+                            )
+
+                            # Filter packages based on matches
+                            filtered_packages = [
+                                p
+                                for p in packages
+                                if p["package_name"]
+                                in [m[0] for m in matches if m[1] > 50]
+                            ]
+
+                            if not filtered_packages:
+                                cls.logger.warning(
+                                    f"No matches found for '{search_term}'. Showing all apps."
+                                )
+                                filtered_packages = packages
+                        else:
+                            filtered_packages = packages
+
+                        # Re-display filtered packages
+                        app_type = "User-Installed" if not show_all else "All"
+                        click.echo(
+                            f"\n{Fore.CYAN}=== {app_type} Applications ({len(filtered_packages)}) ==={Style.RESET_ALL}"
+                        )
+
+                        for idx, pkg in enumerate(filtered_packages, 1):
+                            install_date = pkg.get("install_date", "Unknown")
+                            pkg_name = pkg["package_name"]
+                            if len(pkg_name) > 50:
+                                pkg_name = pkg_name[:47] + "..."
+
+                            type_indicator = ""
+                            if show_all and pkg.get("is_user_app", False):
+                                type_indicator = f" {Fore.BLUE}[USER]{Style.RESET_ALL}"
+
+                            print(
+                                f"{Fore.YELLOW}{idx:3d}.{Style.RESET_ALL} "
+                                f"{Fore.GREEN}{pkg_name:50s}{Style.RESET_ALL}"
+                                f"{type_indicator} "
+                                f"{Fore.CYAN}[{install_date}]{Style.RESET_ALL}"
+                            )
+                        continue  # Go back to selection prompt
+
+                    selected_idx = int(selection_input)
+
+                    if 1 <= selected_idx <= len(filtered_packages):
+                        selected_package = filtered_packages[selected_idx - 1][
+                            "package_name"
+                        ]
+                        cls.logger.info(f"Selected: {selected_package}")
+                        return selected_package
+                    print(
+                        f"{Fore.RED}Invalid number. Please enter 1-{len(filtered_packages)}{Style.RESET_ALL}"
+                    )
+                except ValueError:
+                    if has_fuzzy and filtered_packages == packages:
+                        print(
+                            f"{Fore.RED}Invalid input. Please enter a number, 'f' to filter, or 'q'{Style.RESET_ALL}"
+                        )
+                    else:
+                        print(
+                            f"{Fore.RED}Invalid input. Please enter a number or 'q'{Style.RESET_ALL}"
+                        )
+                except KeyboardInterrupt:
+                    cls.logger.info("\nSelection cancelled by user")
+                    return None
+
+        except Exception as e:
+            cls.logger.error(f"Error during app selection: {e}")
+            return None
+
     @classmethod
     def get_spotlighted_app_data_path(cls):
         """Returns the /data/data/<spotlight_application> path if a spotlight app is set.
         Otherwise, returns None and logs a warning.
         """
+        if cls._spawn_mode and cls._spotlight_spawn_application:
+            return f"/data/data/{cls._spotlight_spawn_application}"
         if not cls._spotlight_application:
             cls.logger.warning("No spotlight application is set.")
             return None
@@ -945,8 +1447,8 @@ class Toolbox:
             else:
                 cls.logger.info(f"Pulled {file_path} to {target}")
 
-            # For .db files, also pull WAL and journal files if they exist
-            if file_path.endswith(".db"):
+            # For SQLite database files, also pull WAL and journal files if they exist
+            if is_sqlite_file(target):
                 wal_file = file_path + "-wal"
                 journal_file = file_path + "-journal"
 
@@ -1044,6 +1546,7 @@ class Toolbox:
                 shell=True,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE,
+                start_new_session=True,
             )
             time.sleep(5)
         cls.logger.info("Starting Emulator")
@@ -1054,6 +1557,7 @@ class Toolbox:
             shell=True,
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
+            start_new_session=True,
         )
         time.sleep(5)
 
@@ -1091,9 +1595,9 @@ class Toolbox:
         # Get the host IP address
         host_ip = cls.get_host_ip()
         cls.logger.info(f"Enter proxy IP (default: {host_ip})")
-        proxy_ip = input().strip() or host_ip
+        proxy_ip = cls.safe_input() or host_ip
         cls.logger.info("Enter proxy port (default: 8080)")
-        proxy_port = input().strip() or "8080"
+        proxy_port = cls.safe_input() or "8080"
 
         stdout, stderr = Adb.send_adb_command(
             f"shell settings put global http_proxy {proxy_ip}:{proxy_port}"
@@ -1168,7 +1672,7 @@ class Toolbox:
             filename = f"{screenshots_dir}/{filename}"
 
         # Take the screenshot using the telnet command
-        cls.logger.info(f"Taking screenshot: {Fore.GREEN}{filename}{Style.RESET_ALL}")
+        cls.logger.info(f"Taking screenshot: {filename}")
 
         # Use the specified telnet command
         stdout, stderr = Adb.send_telnet_command(f"screenrecord screenshot {filename}")
@@ -1177,7 +1681,7 @@ class Toolbox:
             cls.logger.error(f"Failed to capture screenshot: {stderr}")
             return None
 
-        cls.logger.info(f"Screenshot saved to {Fore.GREEN}{filename}{Style.RESET_ALL}")
+        cls.logger.info(f"Screenshot saved to {filename}")
         return filename
 
     @classmethod
@@ -1220,9 +1724,7 @@ class Toolbox:
             return False
 
         cls._screen_recording_running = True
-        cls.logger.info(
-            f"Started screen recording to {Fore.GREEN}{cls._screen_recording_file}{Style.RESET_ALL}"
-        )
+        cls.logger.info(f"Started screen recording to {cls._screen_recording_file}")
         return True
 
     @classmethod
@@ -1243,9 +1745,7 @@ class Toolbox:
             cls.logger.error(f"Failed to stop screen recording: {stderr}")
             return False
 
-        cls.logger.info(
-            f"Screen recording saved to {Fore.GREEN}{cls._screen_recording_file}{Style.RESET_ALL}"
-        )
+        cls.logger.info(f"Screen recording saved to {cls._screen_recording_file}")
         cls._screen_recording_running = False
         return True
 
@@ -1267,11 +1767,26 @@ class Toolbox:
             proxy_string = f"{Fore.GREEN}{proxy_settings}{Fore.RESET}"
         proxy_string = f"HTTP Proxy: [{proxy_string}]"
 
-        spotlight_application = cls._spotlight_application
-        if spotlight_application:
-            spotlight_application_string = f"{Fore.YELLOW}{spotlight_application[0]}, PID: {cls._spotlight_application_pid}{Fore.RESET}"
+        # Spotlight application with spawn/attach mode indicator
+        if cls._spawn_mode and cls._spotlight_spawn_application:
+            # SPAWN MODE
+            spotlight_application_string = (
+                f"{Fore.YELLOW}🚀 {cls._spotlight_spawn_application}{Fore.RESET}"
+            )
+            if cls._auto_resume_after_spawn:
+                spotlight_application_string += (
+                    f" {Fore.GREEN}(auto-resume){Fore.RESET}"
+                )
+            else:
+                spotlight_application_string += (
+                    f" {Fore.YELLOW}(manual resume){Fore.RESET}"
+                )
+        elif cls._spotlight_application:
+            # ATTACH MODE
+            spotlight_application_string = f"{Fore.YELLOW}📌 {cls._spotlight_application[0]}, PID: {cls._spotlight_application_pid}{Fore.RESET}"
         else:
             spotlight_application_string = f"{Fore.RED}Not set{Fore.RESET}"
+
         spotlight_application_string = (
             f"Spotlight Application: [{spotlight_application_string}]"
         )
@@ -1295,10 +1810,26 @@ class Toolbox:
 
         spotlight_files_string = f"Spotlight Files: [{spotlight_files_string}]"
 
+        # Mode indicator for Frida-based tools
+        mode_indicator = ""
+        if cls._spawn_mode:
+            mode_indicator = f" {Fore.CYAN}[🚀 SPAWN]{Fore.RESET}"
+        elif cls._spotlight_application:
+            mode_indicator = f" {Fore.GREEN}[📌 ATTACH]{Fore.RESET}"
+
         if cls.malware_monitor_running == False:
-            malware_monitor_string = f"* start android {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}m{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}alware monitor (dexray-intercept) on spotlight app"
+            malware_monitor_string = f"* start android {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}m{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}alware monitor (dexray-intercept){mode_indicator}"
         else:
-            malware_monitor_string = f"* stop android {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}m{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}alware monitor (dexray-intercept) on {spotlight_application}"
+            current_app = (
+                cls._spotlight_spawn_application
+                if cls._spawn_mode
+                else (
+                    cls._spotlight_application[0]
+                    if cls._spotlight_application
+                    else "app"
+                )
+            )
+            malware_monitor_string = f"* stop android {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}m{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}alware monitor (dexray-intercept) on {current_app}"
 
         # Network capture menu text changes based on capture status
         if cls._network_capture_running:
@@ -1326,11 +1857,12 @@ class Toolbox:
     * {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}i{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}mport action
 
     {Fore.CYAN}=== Spotlight Application ==={Fore.RESET}
-    * set {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}c{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}urrent app in focus as spotlight app
+    * set {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}c{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}urrent app in focus as spotlight app {Fore.GREEN}[📌 ATTACH MODE]{Fore.RESET}
+    * select app with {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}Shift+C{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET} for spawning {Fore.CYAN}[🚀 SPAWN MODE]{Fore.RESET}
     * {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}a{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}nalyze spotlight app with dexray-insight
-    * {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}d{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}ump memory of spotlight app (using fridump)
+    * {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}d{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}ump memory of spotlight app{mode_indicator}
     {malware_monitor_string}
-    * start o{Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}b{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}jection interactive shell for spotlight app
+    * start o{Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}b{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}jection interactive shell{mode_indicator}
     * run {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}t{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}rigdroid malware triggers
 
     {Fore.CYAN}=== Spotlight Files ==={Fore.RESET}
@@ -1349,7 +1881,7 @@ class Toolbox:
 
     {Fore.CYAN}=== Network Management ==={Fore.RESET}
     * set/unset network prox{Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}y{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}
-    * {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}h{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}ook encryption routines with friTap
+    * {Fore.LIGHTMAGENTA_EX}[{Style.BRIGHT}h{Style.RESET_ALL}{Fore.LIGHTMAGENTA_EX}]{Fore.RESET}ook and install key extraction with friTap{mode_indicator}
     {network_capture_string}
 
 
@@ -1585,7 +2117,7 @@ class Toolbox:
             )
             return
 
-        action_name = input("Name your action for export: ")
+        action_name = cls.safe_input("Name your action for export: ")
 
         if os.path.exists(f"{action_name}.action"):
             cls.logger.error(
